@@ -174,6 +174,12 @@ def create_specialties_flag(df):
 
 def correct_C80_success_code(df):
         # C80 has an special conversion Status, setting it to 14 like the other campaigns
+
+    # Correcting non perfect conversions
+    df.loc[(df['idCampaign']=='80')& 
+            (df['BV'].notna()),'IDEmailStatus']==2
+    df.loc[df['idCampaign']=='80'& 
+            df['BV'].notna(),'BV']==np.nan
     aux=df.loc[(df['idCampaign'] == '80') &
             (df['IDEmailStatus'] ==31)].shape
     logger.info(f'C80 successes: {aux}')
@@ -186,6 +192,14 @@ def correct_C80_success_code(df):
 
     return df
 
+def correct_C90_dates(df):
+    # C90 changed it's configuration in may 2021, so we need to eliminate records before
+    C90_start_date = datetime.datetime.strptime( '2021-05-01', '%Y-%m-%d').date()
+    logger.info(f'shape before C90 date correction: {df.shape}')
+    df=df.loc[~ ( (df['idCampaign']=='90') & (df['campaign_bulk_date'] < C90_start_date) ) ]
+    logger.info(f'shape after C90 date correction: {df.shape}')
+    return df
+
 
 def set_idemailstatus_target_column(df):
 
@@ -288,7 +302,7 @@ def create_company_years_column(df):
     CurrentYear = date.today().year
     df['YearFounded'] = df['YearFounded'].fillna(0)
     df['CompanyYears']= CurrentYear-df['YearFounded']
-    df.loc[(df['CompanyYears'] < 0) | (df['CompanyYears'] > 150),'CompanyYears'] = np.nan
+    df.loc[(df['CompanyYears'] < 0) | (df['CompanyYears'] > 250),'CompanyYears'] = np.nan
     df = df.drop(['YearFounded'], axis=1)
     return df
 
